# hdbconnect-py

[![PyPI](https://img.shields.io/pypi/v/pyhdb_rs.svg)](https://pypi.org/project/pyhdb_rs/)
[![codecov](https://codecov.io/gh/bug-ops/pyhdb-rs/graph/badge.svg?token=75RR61N6FI&flag=hdbconnect-py)](https://codecov.io/gh/bug-ops/pyhdb-rs)

Python bindings for SAP HANA via hdbconnect.

## Features

- DB-API 2.0 compliant Connection and Cursor
- Zero-copy Arrow data transfer via PyCapsule Interface
- Native Polars/pandas integration

